@@ -1,12 +1,9 @@
 import sys
 
-sys.path.insert(0, '../src')
-from frontiersman.gameboard.NodeRoads import *
 
-
-def buildRoadCheck(actor, free=False):
+def build_road_check(actor, free=False):
     hand = actor.resourceHand
-    if (free and actor.numRoads > 0):
+    if free and actor.numRoads > 0:
         return True
     if hand.brick < 1 or hand.lumber < 1 or actor.numRoads == 0:
         return False
@@ -14,21 +11,21 @@ def buildRoadCheck(actor, free=False):
         return True
 
 
-def buildRoadAvailable(actor, free=False):
-    toReturn = list()
-    if buildRoadCheck(actor, free):
+def build_road_available(actor, free=False):
+    to_return = list()
+    if build_road_check(actor, free):
         for edgeBase in actor.ownedRoads:
             for corner in edgeBase.corners:
                 for edge in corner.edges:
                     if edge is not None:
-                        if edge.available and edge not in toReturn:
-                            toReturn.append(edge)
-        return toReturn
+                        if edge.available and edge not in to_return:
+                            to_return.append(edge)
+        return to_return
     else:
-        return toReturn
+        return to_return
 
 
-def buildSettlementCheck(actor):
+def build_settlement_check(actor):
     hand = actor.resourceHand
     if hand.brick < 1 or hand.lumber < 1 or hand.grain < 1 or hand.wool < 1 or actor.numSettlements == 0:
         return False
@@ -36,9 +33,9 @@ def buildSettlementCheck(actor):
         return True
 
 
-def buildSettlementAvailable(actor):
+def build_settlement_available(actor):
     toReturn = list()
-    if buildSettlementCheck(actor):
+    if build_settlement_check(actor):
         for edgeBase in actor.ownedRoads:
             for corner in edgeBase.corners:
                 if corner.available and corner not in toReturn:
@@ -48,7 +45,7 @@ def buildSettlementAvailable(actor):
         return toReturn
 
 
-def buildCityCheck(actor):
+def build_city_check(actor):
     hand = actor.resourceHand
     if hand.grain < 2 or hand.ore < 3:  # or actor.numCities == 0 or actor.numSettlements == 5:
         return False
@@ -56,9 +53,9 @@ def buildCityCheck(actor):
         return True
 
 
-def buildCityAvailable(actor):
+def build_city_available(actor):
     toReturn = list()
-    if buildCityCheck(actor):
+    if build_city_check(actor):
         for corner in actor.ownedNodes:
             if not corner.city:
                 toReturn.append(corner)
@@ -67,7 +64,7 @@ def buildCityAvailable(actor):
         return toReturn
 
 
-def buyDevelopmentCheck(actor):
+def buy_development_check(actor):
     hand = actor.resourceHand
     if hand.grain < 1 or hand.ore < 1 or hand.wool < 1:
         return False
@@ -75,8 +72,10 @@ def buyDevelopmentCheck(actor):
         return True
 
 
-def buyDevelopment(actor, bank):
-    if buyDevelopmentCheck(actor):
+# todo not used
+
+def buy_development(actor, bank):
+    if buy_development_check(actor):
         '''
         randomCard = random.uniform(0, bank.totalDevelopments)
 
@@ -116,5 +115,6 @@ def buyDevelopment(actor, bank):
         return None
 
 
+# todo not used
 def trade(offeredCards, requestedCards, playerResources, bankResources):
     pass
